@@ -32,7 +32,7 @@
   #define XDMF_BYTE_ORDER_LITTLE
 #endif
 
-#define XDMF_SYSTEM Linux-4.20.12-arch1-1-ARCH
+#define XDMF_SYSTEM Linux-4.19.79-2-lts
 
 #define XDMF_VOID_VALID
 #ifndef XDMF_VOID_VALID
